==> gsequencer_6.5.2.orig.tar.gz: gsequencer-6.5.2/ags/app/ags_ui_enums.c <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2023 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>

#include <ags/libags.h>

#include <ags/app/ags_ui_enums.h>

/**
 * SECTION:ags_ui_enums
 * @short_description: ui enumerations
 * @title: AgsUiEnums
 * @section_id:
 * @include: ags/audio/ags_ui_enums.h
 *
 * Enumerations related to ui.
 */

GType
ags_ui_recall_flags_get_type()
{
  static volatile gsize g_flags_type_id__volatile;

  if(g_once_init_enter (&g_flags_type_id__volatile)){
    static const GFlagsValue values[] = {
      { AGS_UI_RECALL_MAPPED, "AGS_UI_RECALL_MAPPED", "ui-recall-mapped" },
      { AGS_UI_RECALL_PREMAPPED, "AGS_UI_RECALL_PREMAPPED", "ui-recall-premapped" },
      { 0, NULL, NULL }
    };

    GType g_flags_type_id = g_flags_register_static(g_intern_static_string("AgsUiRecallFlags"), values);

    g_once_init_leave (&g_flags_type_id__volatile, g_flags_type_id);
  }
  
  return g_flags_type_id__volatile;
}

==> gsequencer-8.2.3.tar.gz: gsequencer-8.2.3/ags/app/ags_ui_enums.c <==
/* GSequencer - Advanced GTK Sequencer
 * Copyright (C) 2005-2023 Joël Krähemann
 *
 * This file is part of GSequencer.
 *
 * GSequencer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSequencer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSequencer.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>

#include <ags/libags.h>

#include <ags/app/ags_ui_enums.h>

/**
 * SECTION:ags_ui_enums
 * @short_description: ui enumerations
 * @title: AgsUiEnums
 * @section_id:
 * @include: ags/audio/ags_ui_enums.h
 *
 * Enumerations related to ui.
 */

GType
ags_ui_recall_flags_get_type()
{
  static gsize g_flags_type_id__static;

  if(g_once_init_enter(&g_flags_type_id__static)){
    static const GFlagsValue values[] = {
      { AGS_UI_RECALL_MAPPED, "AGS_UI_RECALL_MAPPED", "ui-recall-mapped" },
      { AGS_UI_RECALL_PREMAPPED, "AGS_UI_RECALL_PREMAPPED", "ui-recall-premapped" },
      { 0, NULL, NULL }
    };

    GType g_flags_type_id = g_flags_register_static(g_intern_static_string("AgsUiRecallFlags"), values);

    g_once_init_leave(&g_flags_type_id__static, g_flags_type_id);
  }
  
  return(g_flags_type_id__static);
}
